<template>
  <div>
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
      @submit.native.prevent
      style="margin-top: 20px; margin-left: 20px"
    >
      <el-form-item label="模板名称" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入模板名称"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>
    <el-table
      v-loading="loading"
      :data="templateList"
      border
      style="width: 98%; margin-left: 20px"
    >
      <el-table-column label="名称" align="center" prop="name" />
      <el-table-column label="描述" align="center" prop="remark" />
      <el-table-column label="模板类型" align="center" prop="flag">
        <template slot-scope="scope">
          <dict-tag
            :options="dict.type.report_template_type"
            :value="scope.row.flag"
          />
        </template>
      </el-table-column>
      <el-table-column
        label="模板状态"
        align="center"
        prop="open"
        width="100px"
      >
        <template slot-scope="scope">
          <el-switch
            v-model="scope.row.open"
            active-value="0"
            inactive-value="1"
            @change="changeSwitch(scope.row)"
          ></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="生成类型" align="center" prop="print" />
      <el-table-column label="地址" align="center" prop="url" />
      <el-table-column label="更新人" align="center" prop="updateBy" />
      <el-table-column label="更新时间" align="center" prop="updateTime" />
      <el-table-column label="创建时间" align="center" prop="createTime" />
      <el-table-column label="创建人" align="center" prop="createBy" />
     
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
        fixed="right"
        width="80px"
      >
        <template slot-scope="scope">
          <el-button
            type="text"
            icon="el-icon-view"
            @click="showPre(scope.row)"
            title="预览"
          >
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:yydm:edit']"
            title="修改"
          ></el-button>
        </template>
      </el-table-column>
    </el-table>

    <!-- 修改报告模板对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="名称" prop="name">
          <el-input v-model="form.name" placeholder="请输入名称" />
        </el-form-item>
        <el-form-item label="描述" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入描述" />
        </el-form-item>
        <el-form-item label="模板类型" prop="flag" >
          <el-select v-model="form.flag" placeholder="请选择模板类型" clearable disabled>
          <el-option v-for="dict in dict.type.report_template_type" :key="dict.value" :label="dict.label" :value="dict.value" />
        </el-select>
        </el-form-item>
        <el-form-item label="生成类型" prop="print" >
          <el-input v-model="form.print" placeholder="请输入描述" disabled/>
        </el-form-item>
        <el-form-item label="地址" prop="url" v-if="form.print == '报表'">
          <el-input v-model="form.url" placeholder="请输入描述" />
        </el-form-item>
        <!-- <el-form-item label="模板状态" prop="open">
          <el-switch
            v-model="form.open"
            active-value="0"
            inactive-value="1"
             @change="changeSwitch1"
          ></el-switch>
        </el-form-item> -->
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
    <el-dialog
      title="模板预览"
      :visible.sync="dialogVisible"
      :close-on-click-modal="false"
    >
      <div class="main">
        <iframe
          id="printIframe"
          :src="url"
          frameborder="0"
          style="width: 100%; height: 100%"
        ></iframe>
      </div>
    </el-dialog>
    <div class="pag">
      <div class="pag1">
        <pagination
          v-show="total > 0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </div>
    </div>
  </div>
</template>
<script>
import {
  listTemplate,
  preShow,
  changeOpen,
  getTemplate,
  updateTemplate
} from "@/api/hosp/template";
import ViewPdf from "@/components/ViewPdf";

export default {
  components: {
    ViewPdf,
  },
  name: "Template",
  dicts: ["sys_normal_disable", "report_template_type","report_template_type"],
  data() {
    return {
      dmKsList: [],
      url: "",
      dialogVisible: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 报告模板表格数据
      templateList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        template: null,
        deleted: null,
        flag: null,
        name: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询报告模板列表 */
    getList() {
      this.loading = true;
      listTemplate(this.queryParams).then((response) => {
        this.templateList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        reportTemId: null,
        template: null,
        createTime: null,
        createBy: null,
        updateTime: null,
        updateBy: null,
        deleted: "0",
        flag: "0",
        name: null,
        remark: null,
        name: null,
        open: "0",
      };
      this.resetForm("form");
    },

    // 开关事件
    changeSwitch(row) {
      let text = row.open === "0" ? "启用" : "停用";
      this.$modal
        .confirm('确认要"' + text + '""' + row.name + '"模板吗？')
        .then(function () {
          return changeOpen(row.reportTemId, row.open);
        })
        .then(() => {
          this.$modal.msgSuccess(text + "成功");
          this.getList();
        })
        .catch(function () {
          row.open = row.open === "0" ? "1" : "0";
        });
    },

    //预览
    showPre(row) {
      const reportTemId = row.reportTemId;
      const flag = true;
      preShow(reportTemId, flag).then((response) => {
        if (response.size === 0) {
          this.$message.error("模板预览出错了,请联系工作人员！");
          this.dialogVisible = false;
        } else {
          this.dialogVisible = true;
          this.url = window.webkitURL.createObjectURL(response); //将后端返回的blob文件读取出url
        }
      });
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const reportTemId = row.reportTemId || this.ids;
      getTemplate(reportTemId).then((response) => {
        this.form = response.data;
        this.dmKsList = response.data.dmKsList;
        this.open = true;
        this.title = "报告模板维护";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          this.form.dmKsList = this.dmKsList;
          if (this.form.reportTemId != null) {
            updateTemplate(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addTemplate(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
  },
};
</script>
<style lang="scss">
.main {
  height: 700px;
  overflow: hidden;
}
.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}
.pag1 {
  width: 30%;
}
</style>

